devtools/cwtwill.py
branchtls-sprint
changeset 1802 d628defebc17
parent 0 b97547f5f1fa
child 1977 606923dff11b
--- a/devtools/cwtwill.py	Thu May 14 10:24:56 2009 +0200
+++ b/devtools/cwtwill.py	Thu May 14 11:38:40 2009 +0200
@@ -1,4 +1,9 @@
-"""cubicweb extensions for twill"""
+"""cubicweb extensions for twill
+
+:organization: Logilab
+:copyright: 2001-2009 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
+:contact: http://www.logilab.fr/ -- mailto:contact@logilab.fr
+"""
 
 import re
 from urllib import quote
@@ -24,9 +29,9 @@
                 # if url is specified linkurl must match
                 if url and linkurl != url:
                     continue
-                return        
+                return
     raise AssertionError('link %s (%s) not found' % (text, url))
-        
+
 
 def view(rql, vid=''):
     """
@@ -56,7 +61,7 @@
     twc.go('view?rql=%s&vid=edition' % quote(rql))
 
 
-        
+
 
 def setvalue(formname, fieldname, value):
     """
@@ -104,5 +109,5 @@
     browser._browser.form = form
     browser.submit(submit_button)
 
-    
+
 # missing actions: delete, copy, changeview